#!/usr/bin/env python3

import sys
from math import sqrt
from config import *

GAUSS = 0.01720209895
GM = GAUSS*GAUSS*365.25*365.25	# UNITS: JULIAN YEARS, AU, SUN MASS
AU = 1.49597870e11		# IN METERS
FACTOR = AU/365.25/86400.	# CONVERSION FACTOR FROM AU/YR TO M/S
SQRFAC = FACTOR**2

def d1_sq(a1,e1,i1,a2,e2,i2):
    return 2. * GM/(a1+a2) * SQRFAC * (1.25 * (2.00*(a2-a1)/(a2+a1))**2 + 2.00 * (e2-e1)**2 + 2.00 * (i2-i1)**2)

def kvadr_rce(a, b, c):
    D = b**2 - 4.0*a*c
    if D < 0.0:
        x1 = None
        x2 = None
    else:
        x1 = (-b + sqrt(D))/(2.0*a)
        x2 = (-b + sqrt(D))/(2.0*a)
    return x1, x2

a1 = []
e1 = []
i1 = []
comment = ""
f = open("family.list", "r")
for line in f:
    if len(line) > 1 and line[0:1] == "#":
        comment += line
    elif len(line) > 1 and line[0:1] != "#":
        l = line.split()
        a1.append(float(l[35])) 
        e1.append(float(l[36])) 
        i1.append(float(l[37])) 
f.close()

amin = min(a1)
amax = max(a1)
emin = min(e1)
emax = max(e1)
imin = min(i1)
imax = max(i1)

v2 = float(v_halo)**2

amean = 0.5*(amin+amax)
f = 1.0/v2*GM/amean*SQRFAC*1.25*4
x1, x2 = kvadr_rce((1.0-f), 2.0*amin*(1.0+f), amin**2*(1.0-f))
a2 = min(x1,x2)
da = amin-a2
de = sqrt(v2/(GM/amean*SQRFAC*2))
di = de

print("v = ", sqrt(v2), " m/s")
print("da = ", da, " au")
print("de = ", de)
print("di = ", di)

comment += "\n# catalogue_halo = %s\n# v_halo = %s m/s\n" % (catalogue_halo, v_halo)

f = open(catalogue_halo, "r")
fout = open("halo.list", "w")
fout.write(comment + "\n")

i = 0
for line in f:
    i += 1
    l = line.split()
    if l[35] == "?":
        continue
    a2 = float(l[35])
    e2 = float(l[36])
    i2 = float(l[37])
    if a2 < amin-da or a2 > amax+da or e2 < emin-de or e2 > emax+de or i2 < imin-di or i2 > imax+di:
        continue
    for j in range(0,len(a1)):
        if d1_sq(a1[j],e1[j],i1[j],a2,e2,i2) <= v2:
            fout.write(line)
            print("i = ", i, ", j = ", j)
            break

f.close()
fout.close()


